@@ -9,10 +9,12 @@ import { AutoApprove } from "./projenrc/auto-approve";
 import { Automerge } from "./projenrc/automerge";
 import { JsiiDocgen } from "./projenrc/custom-docgen";
 import { CustomizedLicense } from "./projenrc/customized-license";
+import { UpgradeCDKTF } from "./projenrc/upgrade-cdktf";
 
 const githubActionPinnedVersions = {
   "actions/checkout": "c85c95e3d7251135ab7dc9ce3241c5835cc595a9", // v3.5.3
   "actions/download-artifact": "9bc31d5ccc31df68ecc42ccf4149144866c47d8a", // v3.0.2
+  "actions/github-script": "d7906e4ad0b1822421a7e6a35d5ca353c962f410", // v6.4.1
   "actions/setup-node": "64ed1c7eab4cce3362f8c340dee64e5eaeef8f7c", // v3.6.0
   "actions/upload-artifact": "0b7f8abb1508181956e8e162db84b466c27e18ce", // v3.1.2
   "amannn/action-semantic-pull-request":
@@ -39,9 +41,9 @@ const project = new ConstructLibraryCdktf({
     },
   },
   minMajorVersion: 1,
-  cdktfVersion: ">=0.14.0",
+  cdktfVersion: "0.18.0",
   description:
-    "A drop-in replacement for cdktf.TerraformStack that let's you define Terraform modules as construct" /* The description is just a string that helps people understand the purpose of the package. */,
+    "A drop-in replacement for cdktf.TerraformStack that lets you define Terraform modules as constructs" /* The description is just a string that helps people understand the purpose of the package. */,
   workflowGitIdentity: {
     name: "team-tf-cdk",
     email: "github-team-tf-cdk@hashicorp.com",
@@ -67,16 +69,19 @@ const project = new ConstructLibraryCdktf({
     packageName: "tfmodulestack",
   },
   docgen: false,
+  jsiiVersion: "^5.1.0",
+  pullRequestTemplate: false,
 });
 
 new CustomizedLicense(project);
 new AutoApprove(project);
 new Automerge(project);
+new UpgradeCDKTF(project);
 
-project.addPeerDeps("cdktf@>=0.15.0", "constructs@^10.0.25");
+project.addPeerDeps("cdktf@>=0.18.0", "constructs@^10.0.25");
 project.addDevDeps(
-  "@cdktf/provider-null@>=5.0.0",
-  "@cdktf/provider-random@>=5.0.0"
+  "@cdktf/provider-null@>=8.0.0",
+  "@cdktf/provider-random@>=9.0.0"
 );
 
 new JsiiDocgen(project, {
@@ -102,4 +107,19 @@ Object.entries(githubActionPinnedVersions).forEach(([action, sha]) => {
   project.github?.actions.set(action, `${action}@${sha}`);
 });
 
+const releaseWorkflow = project.tryFindObjectFile(
+  ".github/workflows/release.yml"
+);
+releaseWorkflow?.addOverride("on.push", {
+  branches: ["main"],
+  "paths-ignore": [
+    // don't do a release if the change was only to these files/directories
+    "examples/**",
+    ".github/ISSUE_TEMPLATE/**",
+    ".github/CODEOWNERS",
+    ".github/dependabot.yml",
+    ".github/**/*.md",
+  ],
+});
+
 project.synth();
